==> aws-cdk-scala_2.12-0.5.1-sources.jar: io/burkard/cdk/services/memorydb/CfnCluster.scala <==
package io.burkard.cdk.services.memorydb

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCluster {

  def apply(
    internalResourceId: String,
    aclName: String,
    nodeType: String,
    clusterName: String,
    snapshotArns: Option[List[String]] = None,
    subnetGroupName: Option[String] = None,
    description: Option[String] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    snapshotWindow: Option[String] = None,
    securityGroupIds: Option[List[String]] = None,
    maintenanceWindow: Option[String] = None,
    autoMinorVersionUpgrade: Option[Boolean] = None,
    tlsEnabled: Option[Boolean] = None,
    parameterGroupName: Option[String] = None,
    port: Option[Number] = None,
    snapshotRetentionLimit: Option[Number] = None,
    snapshotName: Option[String] = None,
    kmsKeyId: Option[String] = None,
    snsTopicArn: Option[String] = None,
    engineVersion: Option[String] = None,
    numReplicasPerShard: Option[Number] = None,
    finalSnapshotName: Option[String] = None,
    numShards: Option[Number] = None,
    snsTopicStatus: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.memorydb.CfnCluster =
    software.amazon.awscdk.services.memorydb.CfnCluster.Builder
      .create(stackCtx, internalResourceId)
      .aclName(aclName)
      .nodeType(nodeType)
      .clusterName(clusterName)
      .snapshotArns(snapshotArns.map(_.asJava).orNull)
      .subnetGroupName(subnetGroupName.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .snapshotWindow(snapshotWindow.orNull)
      .securityGroupIds(securityGroupIds.map(_.asJava).orNull)
      .maintenanceWindow(maintenanceWindow.orNull)
      .autoMinorVersionUpgrade(autoMinorVersionUpgrade.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .tlsEnabled(tlsEnabled.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .parameterGroupName(parameterGroupName.orNull)
      .port(port.orNull)
      .snapshotRetentionLimit(snapshotRetentionLimit.orNull)
      .snapshotName(snapshotName.orNull)
      .kmsKeyId(kmsKeyId.orNull)
      .snsTopicArn(snsTopicArn.orNull)
      .engineVersion(engineVersion.orNull)
      .numReplicasPerShard(numReplicasPerShard.orNull)
      .finalSnapshotName(finalSnapshotName.orNull)
      .numShards(numShards.orNull)
      .snsTopicStatus(snsTopicStatus.orNull)
      .build()
}

==> aws-cdk-scala_2.12-0.15.0-sources.jar: io/burkard/cdk/services/memorydb/CfnCluster.scala <==
package io.burkard.cdk.services.memorydb

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCluster {

  def apply(
    internalResourceId: String,
    aclName: String,
    nodeType: String,
    clusterName: String,
    snapshotArns: Option[List[String]] = None,
    subnetGroupName: Option[String] = None,
    description: Option[String] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    snapshotWindow: Option[String] = None,
    securityGroupIds: Option[List[String]] = None,
    maintenanceWindow: Option[String] = None,
    autoMinorVersionUpgrade: Option[Boolean] = None,
    tlsEnabled: Option[Boolean] = None,
    parameterGroupName: Option[String] = None,
    port: Option[Number] = None,
    snapshotRetentionLimit: Option[Number] = None,
    snapshotName: Option[String] = None,
    kmsKeyId: Option[String] = None,
    snsTopicArn: Option[String] = None,
    engineVersion: Option[String] = None,
    numReplicasPerShard: Option[Number] = None,
    finalSnapshotName: Option[String] = None,
    numShards: Option[Number] = None,
    snsTopicStatus: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.memorydb.CfnCluster =
    software.amazon.awscdk.services.memorydb.CfnCluster.Builder
      .create(stackCtx, internalResourceId)
      .aclName(aclName)
      .nodeType(nodeType)
      .clusterName(clusterName)
      .snapshotArns(snapshotArns.map(_.asJava).orNull)
      .subnetGroupName(subnetGroupName.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .snapshotWindow(snapshotWindow.orNull)
      .securityGroupIds(securityGroupIds.map(_.asJava).orNull)
      .maintenanceWindow(maintenanceWindow.orNull)
      .autoMinorVersionUpgrade(autoMinorVersionUpgrade.map(Boolean.box).orNull)
      .tlsEnabled(tlsEnabled.map(Boolean.box).orNull)
      .parameterGroupName(parameterGroupName.orNull)
      .port(port.orNull)
      .snapshotRetentionLimit(snapshotRetentionLimit.orNull)
      .snapshotName(snapshotName.orNull)
      .kmsKeyId(kmsKeyId.orNull)
      .snsTopicArn(snsTopicArn.orNull)
      .engineVersion(engineVersion.orNull)
      .numReplicasPerShard(numReplicasPerShard.orNull)
      .finalSnapshotName(finalSnapshotName.orNull)
      .numShards(numShards.orNull)
      .snsTopicStatus(snsTopicStatus.orNull)
      .build()
}
